@@ -298,13 +298,13 @@ class Record(object):
         events_by_target = {}
         for ev_type, ev_target in self.events:
             events_by_target.setdefault(ev_target, set([])).add(ev_type)
-        for target, target_events in events_by_target.iteritems():
+        for target, target_events in events_by_target.items():
             # if there are several event types for the same target (e.g. added and removed a
             # relation), group them into the "modified" event type
             if len(target_events) > 1:
                 ev_type = 'modified'
             else:
-                ev_type = iter(target_events).next()
+                ev_type = next(iter(target_events))
             targets_per_event_type.setdefault(_(ev_type), []).append(target)
         # now generate proper messages for each event type
         msgs = []
