@@ -539,6 +539,14 @@ def post_build_callback(schema):
             if rtype == 'label_of':
                 rdef.set_action_permissions('delete', ('managers', 'users'))
 
+    # allow deletion of an archive unit, even if within a public profile
+    seda_archive_unit = schema['seda_archive_unit'].rdef(
+        'SEDAArchiveUnit', 'SEDAArchiveTransfer')
+    for action in ('add', 'delete'):
+        seda_archive_unit.set_action_permissions(action, ('managers', 'users'))
+    schema['SEDAArchiveUnit'].set_action_permissions(
+        'delete', ('managers', 'users'))
+
     # reset permissions, unexpectedly changed by seda's post_build_callback
     def sync_perms(erdef, permissions):
         for action, permissions in permissions.items():
