@@ -1,7 +1,8 @@
 # coding: utf-8
+from __future__ import print_function
 import datetime
 
-print 'create Logilab agent'
+print('create Logilab agent')
 agent = create_entity('Agent', name=u'Logilab',
                       start_date=datetime.date(2000, 1, 1))
 create_entity('PhoneNumber', number=u'05 62 17 16 42',
