@@ -15,8 +15,6 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem-ref server objects"""
 
-from six.moves import map as imap
-
 from cubicweb.predicates import match_user_groups, match_kwargs
 from cubicweb.server import Service
 from cubicweb.dataimport.stores import MetadataGenerator
@@ -99,7 +97,7 @@ class EACImportService(eac.EACImportService):
                 extentity.values['authority'] = set([self._authority.cwuri])
             return extentity
 
-        return imap(set_authority_or_naa, extentities)
+        return map(set_authority_or_naa, extentities)
 
 
 class AllocateArk(Service):
