@@ -17,8 +17,6 @@
 
 from functools import wraps
 
-from six import text_type
-
 from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 from logilab.common.registry import yes
@@ -42,7 +40,7 @@ from cubicweb.web.views import (
     urlrewrite,
 )
 
-from cubes.squareui.views.basetemplates import basetemplates
+from cubicweb_squareui.views.basetemplates import basetemplates
 from cubicweb_seda.views import dropdown_button, has_rel_perm, widgets as sedawidgets
 
 from .. import cwuri_url
@@ -182,6 +180,11 @@ def configure_relation_widget(req, div, search_url, title, multiple, validate):
     return sedawidgets.configure_relation_widget(req, div, search_url, title, multiple, validate)
 
 
+ENTITY_CREATION_KWARGS = {
+    'SEDAArchiveUnit': {'unit_type': 'unit_content'},
+}
+
+
 class AddEntityComponent(component.CtxComponent):
     """Component with 'add' link to be displayed in 'same etype' views usually 'SameETypeListView'.
     """
@@ -190,11 +193,10 @@ class AddEntityComponent(component.CtxComponent):
                   & is_instance('AuthorityRecord', 'ConceptScheme',
                                 'SEDAArchiveTransfer', 'SEDAArchiveUnit'))
     context = 'navtop'
-    extra_kwargs = {'SEDAArchiveUnit': {'unit_type': 'unit_content'}}
 
     def render_body(self, w):
         etype = self.cw_rset.description[0][0]
-        w(add_etype_link(self._cw, etype, **self.extra_kwargs.get(etype, {})))
+        w(add_etype_link(self._cw, etype, **ENTITY_CREATION_KWARGS.get(etype, {})))
 
 
 class ImportEntityComponent(component.CtxComponent):
@@ -478,7 +480,7 @@ class SAEMNoResultView(baseviews.NoResultView):
             # rset probably comes from a user RQL query, fall back to default
             # behavior.
             return super(SAEMNoResultView, self).call(**kwargs)
-        if etype not in vreg['etypes']:
+        if etype not in vreg.schema.entities():
             # Or the first select query variable is not the entity type.
             return super(SAEMNoResultView, self).call(**kwargs)
         msg = self._cw._('No entity of type "{etype}" yet.').format(
@@ -487,8 +489,10 @@ class SAEMNoResultView(baseviews.NoResultView):
         self.w(u'<div class="searchMessage">{}'.format(
             xml_escape(msg)))
         if vreg.schema[etype].has_perm(self._cw, 'add'):
+            kwargs = ENTITY_CREATION_KWARGS.get(etype, {})
+            url = vreg['etypes'].etype_class(etype).cw_create_url(self._cw, **kwargs)
             self.w(u' <a href="{url}">{invite}</a>'.format(
-                url=vreg['etypes'].etype_class(etype).cw_create_url(self._cw),
+                url=url,
                 invite=xml_escape(self._cw._('Create one?')),
             ))
         self.w(u'</div>')
@@ -508,7 +512,7 @@ def sort_relation_targets(self, rtype, eids):
     first_item = self._cw.entity_from_eid(eids[0]).cw_adapt_to('ISortable')
     collection = first_item.collection
     for item in collection:
-        index = next(idx for idx, v in enumerate(eids) if v == text_type(item.eid))
+        index = next(idx for idx, v in enumerate(eids) if v == str(item.eid))
         item.cw_set(index=index)
 
 
