@@ -15,8 +15,6 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem-ref views for AuthorityRecord"""
 
-from six import text_type
-
 from logilab.common.date import ustrftime
 from logilab.mtconverter import xml_escape
 
@@ -28,7 +26,7 @@ from cubicweb.predicates import has_related_entities, is_instance, match_kwargs
 from cubicweb.web import formfields as ff, formwidgets as fw
 from cubicweb.web.views import tabs, uicfg
 
-from cubes.relationwidget import views as rwdg
+from cubicweb_relationwidget import views as rwdg
 
 from .. import cwuri_url, user_has_authority
 from . import (ImportEntityComponent, RelatedEntitiesListView, SubviewsTabView,
@@ -550,7 +548,7 @@ class EACSourceListItemView(EntityView):
     __select__ = has_related_entities('source_agent', role='subject')
 
     @editlinks(icon_info=False)
-    def entity_call(self, entity):
+    def entity_call(self, entity, **kwargs):
         if entity.title:
             self.w(tags.h5(entity.title, klass='list-group-item-heading'))
         if entity.description:
@@ -771,7 +769,7 @@ class AuthorityRecordTimelineJsonView(EntityView):
                 continue
             data['date'].append(self.entity_as_date(
                 successor, tag=self._cw._('chronological_successor')))
-        self.w(json_dumps({'timeline': data}))
+        self.w(json_dumps({'timeline': data}).encode('utf-8'))
 
     @staticmethod
     def entity_as_date(entity, tag):
@@ -791,7 +789,7 @@ class AuthorityRecordTimelineJsonView(EntityView):
 
 def _node(entity):
     return {
-        'id': text_type(entity.eid),
+        'id': str(entity.eid),
         'title': cut(entity.dc_title(), 30),
     }
 
