@@ -38,7 +38,7 @@ class EACExportTC(CubicWebTC):
             cnx.create_entity('Activity', agent=u'007', start=datetime.utcnow(),
                               generated=record)
             cnx.commit()
-            eac_xml = record.cw_adapt_to('EAC-CPF').dump()
+            eac_xml = record.cw_adapt_to('EAC-CPF').dump().decode('utf-8')
             self.assertIn('<agent>admin</agent>', eac_xml)
             self.assertIn('<agent>007</agent>', eac_xml)
 
@@ -54,6 +54,7 @@ class EACExportTC(CubicWebTC):
             schema = etree.XMLSchema(etree.parse(self.datapath('cpf.xsd')))
             schema.assert_(etree.fromstring(xml))
 
+            xml = xml.decode('utf-8')
             self.assertIn('<recordId>{0}</recordId>'.format(record.ark.replace('/', '-')), xml)
             self.assertIn('<otherRecordId>My RID</otherRecordId>', xml)
             self.assertIn('<otherRecordId>Other RID</otherRecordId>', xml)
