@@ -97,13 +97,13 @@ class ArkURLTC(testlib.CubicWebTC):
 class MyValueGenerator(ValueGenerator):
 
     def generate_Any_ark(self, entity, index):
-        return '/'.join([
-            ''.join(random.sample('0123456789', 5)),
-            ''.join(random.sample('qwertyuvckj87932141', 10)),
-        ]).decode('ascii')
+        return u'/'.join([
+            u''.join(random.sample(u'0123456789', 5)),
+            u''.join(random.sample(u'qwertyuvckj87932141', 10)),
+        ])
 
     def generate_ArkNameAssigningAuthority_what(self, entity, index):
-        return int(''.join(random.sample('0123456789', 5)))
+        return int(u''.join(random.sample(u'0123456789', 5)))
 
 
 class AutomaticWebTest(testlib.AutomaticWebTest):
