@@ -180,7 +180,7 @@ class SAEMRefHooksTC(CubicWebTC):
             self.assertEqual(function.equivalent_concept[0].eid, concept.eid)
             info.cw_clear_all_caches()
             self.assertEqual(info.equivalent_concept[0].eid, concept.eid)
-            self.failIf(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
+            self.assertFalse(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
 
     def test_externaluri_to_authorityrecord_subject(self):
         with self.admin_access.repo_cnx() as cnx:
@@ -194,7 +194,7 @@ class SAEMRefHooksTC(CubicWebTC):
             cnx.commit()
             arelation.cw_clear_all_caches()
             self.assertEqual(arelation.association_to[0], alice)
-            self.failIf(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
+            self.assertFalse(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
 
     def test_externaluri_to_authorityrecord_object(self):
         with self.admin_access.repo_cnx() as cnx:
@@ -208,7 +208,7 @@ class SAEMRefHooksTC(CubicWebTC):
             cnx.commit()
             arelation.cw_clear_all_caches()
             self.assertEqual(arelation.association_from[0], alice)
-            self.failIf(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
+            self.assertFalse(cnx.execute('Any X WHERE X eid %(x)s', {'x': exturi.eid}))
 
     def test_user_email(self):
         # EmailAddress belong to the Organisation graph, hence may conflict with hooks when linked
@@ -540,8 +540,8 @@ class EntityLifeCycleTC(CubicWebTC):
             cnx.commit()
             agent.cw_set(name=u'jones')
             cnx.commit()
-            self.failIf(cnx.find('Activity', type=u'modify',
-                                 used=authorityrecord.eid))
+            self.assertFalse(cnx.find('Activity', type=u'modify',
+                                      used=authorityrecord.eid))
 
     def test_concept(self):
         with self.admin_access.repo_cnx() as cnx:
