@@ -43,7 +43,7 @@ def create_published_records_panel(cnx):
         cnx.commit()
 
 
-class SchemaConstraintsTC(CubicWebTC):
+class SchemaTC(CubicWebTC):
 
     configcls = PostgresApptestConfiguration
     assertValidationError = testutils.assertValidationError
@@ -231,6 +231,37 @@ class SchemaConstraintsTC(CubicWebTC):
             testutils.agent(cnx, u'bob', authority=other_authority)
             cnx.commit()
 
+    def test_can_delete_archiveunit_unlinked_from_public_profile(self):
+        with self.admin_access.cnx() as cnx:
+            transfer = testutils.setup_profile(cnx, title=u'test')
+            unit, _, _ = testutils.create_archive_unit(transfer, cnx=cnx,
+                                                       user_cardinality=u'1',
+                                                       user_annotation=u'plop')
+            cnx.commit()
+            transfer.cw_adapt_to('IWorkflowable').fire_transition('publish')
+            cnx.commit()
+            assert unit in transfer.reverse_seda_archive_unit
+            # First deletion the relation,
+            transfer.cw_set(reverse_seda_archive_unit=None)
+            cnx.commit()
+            # Then delete (old) target.
+            unit.cw_delete()
+            cnx.commit()
+
+    def test_can_delete_archiveunit_from_public_profile(self):
+        with self.admin_access.cnx() as cnx:
+            transfer = testutils.setup_profile(cnx, title=u'test')
+            unit, _, _ = testutils.create_archive_unit(transfer, cnx=cnx,
+                                                       user_cardinality=u'1',
+                                                       user_annotation=u'plop')
+            cnx.commit()
+            transfer.cw_adapt_to('IWorkflowable').fire_transition('publish')
+            cnx.commit()
+            assert unit in transfer.reverse_seda_archive_unit
+            # Delete archive unit while still related to the archive transfer.
+            unit.cw_delete()
+            cnx.commit()
+
 
 class AuthorityRecordTC(CubicWebTC):
 
